<?php

namespace Adonadboard\Account\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Adonadboard\Account\Interfaces\AccountRepositoryInterface;

class AccountPublicController extends BaseController
{
    // use AccountWorkflow;

    /**
     * Constructor.
     *
     * @param type \Adonadboard\Account\Interfaces\AccountRepositoryInterface $account
     *
     * @return type
     */
    public function __construct(AccountRepositoryInterface $account)
    {
        $this->repository = $account;
        parent::__construct();
    }

    /**
     * Show account's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $accounts = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$account::$account.names'))
            ->view('$account::public.account.index')
            ->data(compact('$accounts'))
            ->output();
    }

    /**
     * Show account's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $accounts = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$account::$account.names'))
            ->view('$account::public.account.index')
            ->data(compact('$accounts'))
            ->output();
    }

    /**
     * Show account.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $account = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$account->name . trans('$account::$account.name'))
            ->view('$account::public.account.show')
            ->data(compact('$account'))
            ->output();
    }

}
